@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.003007';
+our $VERSION = '0.003008';
 
 use Moose;
 
 extends 'Throwable::Error';
 
-__PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
+__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 
 1;
 
@@ -26,7 +26,7 @@ Stepford::Error - A Stepford exception object
 
 =head1 VERSION
 
-version 0.003007
+version 0.003008
 
 =head1 DESCRIPTION
 
