@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.003007';
+our $VERSION = '0.003008';
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -20,12 +20,12 @@ sub last_run_time {
 sub run {
     my $self = shift;
 
-    $self->logger()->info('Completed execution');
+    $self->logger->info('Completed execution');
 
     return;
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -41,12 +41,12 @@ Stepford::FinalStep - The final step for all Stepford runs
 
 =head1 VERSION
 
-version 0.003007
+version 0.003008
 
 =head1 DESCRIPTION
 
 This step just logs the message "Completed execution". It is always run as the
-last step when calling C<run()> on a L<Stepford::Runner> object.
+last step when calling C<run> on a L<Stepford::Runner> object.
 
 =for Pod::Coverage .*
 
