@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.003007';
+our $VERSION = '0.003008';
 
 use Stepford::Types qw( Logger Str );
 
@@ -32,12 +32,12 @@ around $Levels => sub {
     my $self    = shift;
     my $message = shift;
 
-    $message = '[' . $self->_moniker() . '] ' . $message;
+    $message = '[' . $self->_moniker . '] ' . $message;
 
     return $self->$orig( $message, @_ );
 };
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -53,7 +53,7 @@ Stepford::LoggerWithMoniker - The logger used by Step classes.
 
 =head1 VERSION
 
-version 0.003007
+version 0.003008
 
 =head1 DESCRIPTION
 
