@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.003007';
+our $VERSION = '0.003008';
 
 use Forest::Tree;
 use List::AllUtils qw( all uniq );
@@ -61,31 +61,30 @@ has logger => (
 sub _build_step_sets {
     my $self = shift;
 
-    my $tree = $self->_make_tree();
+    my $tree = $self->_make_tree;
 
     my @sets;
-    while ( $tree->child_count() ) {
+    while ( $tree->child_count ) {
         my @leaves;
         $tree->traverse(
             sub {
                 my $node = shift;
-                push @leaves, $node if $node->is_leaf();
+                push @leaves, $node if $node->is_leaf;
             }
         );
 
-        push @sets, [ sort( uniq( map { $_->node() } @leaves ) ) ];
+        push @sets, [ sort( uniq( map { $_->node } @leaves ) ) ];
 
         for my $leaf (@leaves) {
-            my $parent = $leaf->parent();
+            my $parent = $leaf->parent;
             $parent->remove_child_at( $parent->get_child_index($leaf) );
         }
     }
 
-    push @sets, [ $tree->node() ];
+    push @sets, [ $tree->node ];
 
-    $self->logger()
-        ->info( 'Plan for '
-            . ( join q{ - }, @{ $self->_final_steps() } ) . ': '
+    $self->logger->info( 'Plan for '
+            . ( join q{ - }, @{ $self->_final_steps } ) . ': '
             . $self->_step_sets_as_string( \@sets ) );
 
     return \@sets;
@@ -99,7 +98,7 @@ sub _make_tree {
     );
 
     my %seen;
-    $self->_add_steps_to_tree( $tree, $self->_final_steps(), \%seen );
+    $self->_add_steps_to_tree( $tree, $self->_final_steps, \%seen );
 
     return $tree;
 }
@@ -110,7 +109,7 @@ sub _add_steps_to_tree {
     my $steps = shift;
     my $seen  = shift;
 
-    my $map = $self->_production_map();
+    my $map = $self->_production_map;
 
     for my $step ( @{$steps} ) {
         $self->_check_tree_for_cycle( $tree, $step );
@@ -121,7 +120,7 @@ sub _add_steps_to_tree {
         $tree->add_child($child);
 
         my %deps;
-        for my $dep ( map { $_->name() } $step->dependencies() ) {
+        for my $dep ( map { $_->name } $step->dependencies ) {
             Stepford::Error->throw(
                       "Cannot resolve a dependency for $step."
                     . " There is no step that produces the $dep attribute." )
@@ -131,8 +130,7 @@ sub _add_steps_to_tree {
                 "A dependency ($dep) for $step resolved to the same step.")
                 if $map->{$dep} eq $step;
 
-            $self->logger()
-                ->debug(
+            $self->logger->debug(
                 "Dependency $dep for $step is provided by $map->{$dep}");
 
             $deps{ $map->{$dep} } = 1;
@@ -148,10 +146,10 @@ sub _check_tree_for_cycle {
     my $step = shift;
 
     ## no critic (ControlStructures::ProhibitCStyleForLoops)
-    for ( my $cur = $tree ; $cur ; $cur = $cur->parent() ) {
+    for ( my $cur = $tree ; $cur ; $cur = $cur->parent ) {
         Stepford::Error->throw(
             "The set of dependencies for $step is cyclical")
-            if $cur->node() eq $step;
+            if $cur->node eq $step;
     }
 
     return;
@@ -161,8 +159,8 @@ sub _build_production_map {
     my $self = shift;
 
     my %map;
-    for my $class ( @{ $self->_step_classes() } ) {
-        for my $attr ( map { $_->name() } $class->productions() ) {
+    for my $class ( @{ $self->_step_classes } ) {
+        for my $attr ( map { $_->name } $class->productions ) {
             next if exists $map{$attr};
 
             $map{$attr} = $class;
@@ -179,7 +177,7 @@ sub _step_sets_as_string {
     return join ' => ', map { '[ ' . ( join ', ', @{$_} ) . ' ]' } @{$sets};
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -195,7 +193,7 @@ Stepford::Plan - Represents a concrete plan for execution by a Stepford::Runner
 
 =head1 VERSION
 
-version 0.003007
+version 0.003008
 
 =head1 DESCRIPTION
 
