@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.003007';
+our $VERSION = '0.003008';
 
 use Carp qw( carp );
 
@@ -19,10 +19,10 @@ override new => sub {
     local $Carp::CarpLevel = $Carp::CarpLevel + 1;
     carp
         'The Stepford::Planner class has been renamed to Stepford::Runner - use Stepford::Runner';
-    return super();
+    return super;
 };
 
-__PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
+__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 
 1;
 
@@ -38,7 +38,7 @@ Stepford::Planner - Renamed to Stepford::Runner
 
 =head1 VERSION
 
-version 0.003007
+version 0.003008
 
 =head1 DESCRIPTION
 
